# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added

### Fixed

### Changed

### Removed

## [0.1.0] - 2025-02-04

### Fixed
- Update version of actions in `ci.yml` workflow file.

### Changed
- Rename all instances of https://github.com/arnab39/reptrix to https://github.com/BARL-SSL/reptrix
- Updated emails and Readme

## [0.0.1] - 2024-12-23

### Added
- Initial release
